==> openjdk-src-13.0.2.u8-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_pt_PT.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_pt_PT extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "ARS", "ARS" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PTE", "\u200b" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "ZAR" },
            { "ZMW", "ZMW" },
            { "afa", "Afeghani (1927\u20132002)" },
            { "afn", "Afegani do Afeganist\u00e3o" },
            { "all", "lek alban\u00eas" },
            { "amd", "Dram arm\u00e9nio" },
            { "aoa", "kwanza angolano" },
            { "ars", "peso argentino" },
            { "awg", "florim de Aruba" },
            { "azn", "Manat do Azerbaij\u00e3o" },
            { "bad", "Dinar da B\u00f3snia-Herzeg\u00f3vina" },
            { "bam", "marco b\u00f3snio-herzeg\u00f3vino convers\u00edvel" },
            { "bbd", "d\u00f3lar barbadense" },
            { "bdt", "Taka de Bangladesh" },
            { "bec", "Franco belga (convert\u00edvel)" },
            { "bgn", "lev b\u00falgaro" },
            { "bhd", "Dinar baremita" },
            { "bif", "franco burundiano" },
            { "bmd", "d\u00f3lar bermudense" },
            { "bnd", "D\u00f3lar brune\u00edno" },
            { "bob", "boliviano" },
            { "brl", "real brasileiro" },
            { "bsd", "d\u00f3lar das Bahamas" },
            { "btn", "Ngultrum do But\u00e3o" },
            { "bwp", "Pula de Botswana" },
            { "byb", "Rublo novo bielorusso (1994\u20131999)" },
            { "byn", "rublo bielorrusso" },
            { "bzd", "d\u00f3lar belizense" },
            { "cad", "d\u00f3lar canadiano" },
            { "cdf", "franco congol\u00eas" },
            { "chf", "franco su\u00ed\u00e7o" },
            { "clp", "peso chileno" },
            { "cnh", "yuan offshore" },
            { "cny", "yuan" },
            { "cop", "peso colombiano" },
            { "crc", "colon costa-riquenho" },
            { "cuc", "peso cubano convers\u00edvel" },
            { "cup", "peso cubano" },
            { "cve", "escudo cabo-verdiano" },
            { "cyp", "Libra de Chipre" },
            { "czk", "coroa checa" },
            { "djf", "franco jibutiano" },
            { "dkk", "coroa dinamarquesa" },
            { "dzd", "dinar argelino" },
            { "ecv", "Unidad de Valor Constante (UVC) do Equador" },
            { "egp", "libra eg\u00edpcia" },
            { "ern", "nakfa eritreia" },
            { "etb", "birr et\u00edope" },
            { "eur", "euro" },
            { "fjd", "D\u00f3lar de Fiji" },
            { "fkp", "libra das Ilhas Falkland" },
            { "gbp", "libra esterlina brit\u00e2nica" },
            { "ghs", "cedi gan\u00eas" },
            { "gip", "libra de Gibraltar" },
            { "gmd", "dalasi gambiano" },
            { "gnf", "franco guineense" },
            { "gtq", "quetzal da Guatemala" },
            { "gyd", "d\u00f3lar da Guiana" },
            { "hnl", "lempira das Honduras" },
            { "hrk", "kuna croata" },
            { "huf", "forint h\u00fangaro" },
            { "ils", "Sheqel novo israelita" },
            { "isk", "coroa islandesa" },
            { "kes", "xelim queniano" },
            { "kgs", "Som do Quirguist\u00e3o" },
            { "kmf", "franco comoriano" },
            { "kyd", "D\u00f3lar das Ilhas Caim\u00e3o" },
            { "kzt", "Tenge do Cazaquist\u00e3o" },
            { "lak", "Kip de Laos" },
            { "lrd", "d\u00f3lar liberiano" },
            { "ltl", "Litas da Litu\u00e2nia" },
            { "lvl", "Lats da Let\u00f3nia" },
            { "lyd", "dinar l\u00edbio" },
            { "mad", "dirham marroquino" },
            { "mdl", "leu moldavo" },
            { "mga", "ariari malgaxe" },
            { "mkd", "dinar maced\u00f3nio" },
            { "mmk", "Kyat de Mianmar" },
            { "mnt", "Tugrik da Mong\u00f3lia" },
            { "mro", "ouguiya mauritana (1973\u20132017)" },
            { "mru", "ouguiya mauritana" },
            { "mur", "rupia mauriciana" },
            { "mvr", "Rupia das Ilhas Maldivas" },
            { "mwk", "kwacha malauiano" },
            { "mxn", "peso mexicano" },
            { "mxp", "Peso Plata mexicano (1861\u20131992)" },
            { "mxv", "Unidad de Inversion (UDI) mexicana" },
            { "mzn", "metical mo\u00e7ambicano" },
            { "nad", "D\u00f3lar da Nam\u00edbia" },
            { "nic", "C\u00f3rdoba nicaraguano (1988\u20131991)" },
            { "nio", "c\u00f3rdoba nicaraguano" },
            { "nok", "coroa norueguesa" },
            { "omr", "Rial de Om\u00e3" },
            { "pab", "balboa do Panam\u00e1" },
            { "pen", "sol peruano" },
            { "pgk", "Kina da Papua-Nova Guin\u00e9" },
            { "pln", "zloti polaco" },
            { "pyg", "guarani paraguaio" },
            { "qar", "Rial do Catar" },
            { "ron", "leu romeno" },
            { "rsd", "dinar s\u00e9rvio" },
            { "rub", "rublo russo" },
            { "rwf", "franco ruand\u00eas" },
            { "sar", "Rial saudita" },
            { "scr", "rupia seichelense" },
            { "sdg", "libra sudanesa" },
            { "sek", "coroa sueca" },
            { "sgd", "D\u00f3lar de Singapura" },
            { "shp", "libra santa-helenense" },
            { "sos", "xelim somali" },
            { "srd", "d\u00f3lar do Suriname" },
            { "ssp", "libra sul-sudanesa" },
            { "stn", "dobra de S\u00e3o Tom\u00e9 e Pr\u00edncipe" },
            { "szl", "Lilangeni da Suazil\u00e2ndia" },
            { "thb", "Baht da Tail\u00e2ndia" },
            { "tjs", "Somoni do Tajaquist\u00e3o" },
            { "tmt", "Manat do Turquemenist\u00e3o" },
            { "tnd", "dinar tunisino" },
            { "top", "Pa\u02bbanga de Tonga" },
            { "ttd", "D\u00f3lar de Trindade e Tobago" },
            { "uah", "hryvnia ucraniano" },
            { "usd", "d\u00f3lar dos Estados Unidos" },
            { "uyu", "peso uruguaio" },
            { "uzs", "Som do Uzbequist\u00e3o" },
            { "vef", "bol\u00edvar (2008\u20132018)" },
            { "ves", "bol\u00edvar" },
            { "xaf", "franco CFA (BEAC)" },
            { "xcd", "D\u00f3lar das Cara\u00edbas Orientais" },
            { "xof", "franco CFA (BCEAO)" },
            { "xxx", "moeda desconhecida" },
            { "zmk", "Kwacha zambiano (1968\u20132012)" },
        };
        return data;
    }
}

==> openjdk-src-15.0.2.u7-1-aarch64.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_pt_PT.java <==
/*
 * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_pt_PT extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "LTL", "LTL" },
            { "LVL", "LVL" },
            { "PTE", "\u200b" },
            { "aed", "dirham dos Emirados \u00c1rabes Unidos" },
            { "afa", "Afeghani (1927\u20132002)" },
            { "afn", "afeg\u00e2ni afeg\u00e3o" },
            { "all", "lek alban\u00eas" },
            { "amd", "dram arm\u00e9nio" },
            { "ang", "florim das Antilhas Holandesas" },
            { "aoa", "kwanza angolano" },
            { "ars", "peso argentino" },
            { "aud", "d\u00f3lar australiano" },
            { "awg", "florim de Aruba" },
            { "azn", "manat azeri" },
            { "bad", "Dinar da B\u00f3snia-Herzeg\u00f3vina" },
            { "bam", "marco b\u00f3snio-herzeg\u00f3vino convers\u00edvel" },
            { "bbd", "d\u00f3lar barbadense" },
            { "bdt", "taka bengali" },
            { "bec", "Franco belga (convert\u00edvel)" },
            { "bgn", "lev b\u00falgaro" },
            { "bhd", "dinar baremita" },
            { "bif", "franco burundiano" },
            { "bmd", "d\u00f3lar bermudense" },
            { "bnd", "d\u00f3lar bruneano" },
            { "bob", "boliviano" },
            { "brl", "real brasileiro" },
            { "bsd", "d\u00f3lar das Bahamas" },
            { "btn", "ngultrum butan\u00eas" },
            { "bwp", "pula de Botswana" },
            { "byb", "Rublo novo bielorusso (1994\u20131999)" },
            { "byn", "rublo bielorrusso" },
            { "bzd", "d\u00f3lar belizense" },
            { "cad", "d\u00f3lar canadiano" },
            { "cdf", "franco congol\u00eas" },
            { "chf", "franco su\u00ed\u00e7o" },
            { "clp", "peso chileno" },
            { "cnh", "yuan offshore" },
            { "cny", "yuan" },
            { "cop", "peso colombiano" },
            { "crc", "colon costa-riquenho" },
            { "cuc", "peso cubano convers\u00edvel" },
            { "cup", "peso cubano" },
            { "cve", "escudo cabo-verdiano" },
            { "cyp", "Libra de Chipre" },
            { "czk", "coroa checa" },
            { "djf", "franco jibutiano" },
            { "dkk", "coroa dinamarquesa" },
            { "dop", "peso dominicano" },
            { "dzd", "dinar argelino" },
            { "ecv", "Unidad de Valor Constante (UVC) do Equador" },
            { "egp", "libra eg\u00edpcia" },
            { "ern", "nakfa eritreia" },
            { "etb", "birr et\u00edope" },
            { "eur", "euro" },
            { "fjd", "d\u00f3lar fijiano" },
            { "fkp", "libra das Ilhas Falkland" },
            { "gbp", "libra esterlina brit\u00e2nica" },
            { "gel", "lari georgiano" },
            { "ghs", "cedi gan\u00eas" },
            { "gip", "libra de Gibraltar" },
            { "gmd", "dalasi gambiano" },
            { "gnf", "franco guineense" },
            { "gtq", "quetzal da Guatemala" },
            { "gyd", "d\u00f3lar da Guiana" },
            { "hkd", "d\u00f3lar de Hong Kong" },
            { "hnl", "lempira das Honduras" },
            { "hrk", "kuna croata" },
            { "htg", "gourde haitiano" },
            { "huf", "forint h\u00fangaro" },
            { "idr", "rupia indon\u00e9sia" },
            { "ils", "sheqel novo israelita" },
            { "inr", "rupia indiana" },
            { "iqd", "dinar iraquiano" },
            { "irr", "rial iraniano" },
            { "isk", "coroa islandesa" },
            { "jmd", "d\u00f3lar jamaicano" },
            { "jod", "dinar jordaniano" },
            { "jpy", "iene japon\u00eas" },
            { "kes", "xelim queniano" },
            { "kgs", "som quirguiz" },
            { "khr", "riel cambojano" },
            { "kmf", "franco comoriano" },
            { "kpw", "won norte-coreano" },
            { "krw", "won sul-coreano" },
            { "kwd", "dinar kuwaitiano" },
            { "kyd", "d\u00f3lar das Ilhas Caim\u00e3o" },
            { "kzt", "tenge cazaque" },
            { "lak", "kip laosiano" },
            { "lbp", "libra libanesa" },
            { "lkr", "rupia do Sri Lanka" },
            { "lrd", "d\u00f3lar liberiano" },
            { "ltl", "Litas da Litu\u00e2nia" },
            { "lvl", "Lats da Let\u00f3nia" },
            { "lyd", "dinar l\u00edbio" },
            { "mad", "dirham marroquino" },
            { "mdl", "leu moldavo" },
            { "mga", "ariari malgaxe" },
            { "mkd", "dinar maced\u00f3nio" },
            { "mmk", "kyat de Mianmar" },
            { "mnt", "tugrik mongol" },
            { "mop", "pataca macaense" },
            { "mro", "ouguiya mauritana (1973\u20132017)" },
            { "mru", "ouguiya mauritana" },
            { "mur", "rupia mauriciana" },
            { "mvr", "rupia maldivana" },
            { "mwk", "kwacha malauiano" },
            { "mxn", "peso mexicano" },
            { "mxp", "Peso Plata mexicano (1861\u20131992)" },
            { "mxv", "Unidad de Inversion (UDI) mexicana" },
            { "myr", "ringgit malaio" },
            { "mzn", "metical mo\u00e7ambicano" },
            { "nad", "d\u00f3lar namibiano" },
            { "ngn", "naira nigeriana" },
            { "nic", "C\u00f3rdoba nicaraguano (1988\u20131991)" },
            { "nio", "c\u00f3rdoba nicaraguano" },
            { "nok", "coroa norueguesa" },
            { "npr", "rupia nepalesa" },
            { "nzd", "d\u00f3lar neozeland\u00eas" },
            { "omr", "rial omanense" },
            { "pab", "balboa do Panam\u00e1" },
            { "pen", "sol peruano" },
            { "pgk", "kina papu\u00e1sia" },
            { "php", "peso filipino" },
            { "pkr", "rupia paquistanesa" },
            { "pln", "zloti polaco" },
            { "pte", "escudo portugu\u00eas" },
            { "pyg", "guarani paraguaio" },
            { "qar", "rial catarense" },
            { "ron", "leu romeno" },
            { "rsd", "dinar s\u00e9rvio" },
            { "rub", "rublo russo" },
            { "rwf", "franco ruand\u00eas" },
            { "sar", "rial saudita" },
            { "sbd", "d\u00f3lar das Ilhas Salom\u00e3o" },
            { "scr", "rupia seichelense" },
            { "sdg", "libra sudanesa" },
            { "sek", "coroa sueca" },
            { "sgd", "d\u00f3lar singapuriano" },
            { "shp", "libra santa-helenense" },
            { "sll", "leone de Serra Leoa" },
            { "sos", "xelim somali" },
            { "srd", "d\u00f3lar do Suriname" },
            { "ssp", "libra sul-sudanesa" },
            { "stn", "dobra de S\u00e3o Tom\u00e9 e Pr\u00edncipe" },
            { "syp", "libra s\u00edria" },
            { "szl", "lilangeni su\u00e1zi" },
            { "thb", "baht tailand\u00eas" },
            { "tjs", "somoni tajique" },
            { "tmt", "manat turcomeno" },
            { "tnd", "dinar tunisino" },
            { "top", "pa\u02bbanga tonganesa" },
            { "try", "lira turca" },
            { "ttd", "d\u00f3lar de Trindade e Tobago" },
            { "twd", "novo d\u00f3lar taiwan\u00eas" },
            { "tzs", "xelim tanzaniano" },
            { "uah", "hryvnia ucraniano" },
            { "ugx", "xelim ugandense" },
            { "usd", "d\u00f3lar dos Estados Unidos" },
            { "uyu", "peso uruguaio" },
            { "uzs", "som uzbeque" },
            { "vef", "bol\u00edvar (2008\u20132018)" },
            { "ves", "bol\u00edvar" },
            { "vnd", "dong vietnamita" },
            { "vuv", "vatu de Vanuatu" },
            { "wst", "tala samoano" },
            { "xaf", "franco CFA (BEAC)" },
            { "xcd", "d\u00f3lar das Cara\u00edbas Orientais" },
            { "xof", "franco CFA (BCEAO)" },
            { "xpf", "franco CFP" },
            { "xxx", "moeda desconhecida" },
            { "yer", "rial iemenita" },
            { "zar", "rand sul-africano" },
            { "zmk", "Kwacha zambiano (1968\u20132012)" },
            { "zmw", "kwacha zambiano" },
        };
        return data;
    }
}
